OlaCameraPosition class

Camera target plus zoom / bearing / tilt.

Constructors

OlaCameraPosition({required OlaLatLng target, double zoom = 15, double bearing = 0, double tilt = 0})
const
OlaCameraPosition.fromJson(Map json)
factory

Properties

bearing → double
final
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
target → OlaLatLng
final
tilt → double
final
zoom → double
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited