OlaMapView class

Inheritance

Constructors

OlaMapView({Key? key, required String apiKey, String tileUrl = kOlaMapsDefaultTileUrl, Object? language, bool mode3d = false, String? threeDTileset, String projectId = '', String? userId, void onMapCreated(int id)?, void onControllerReady(OlaMapController controller)?, void onMapError(String error)?, OlaLatLng? initialCameraPosition, double initialZoom = 15, bool showZoomControls = true, bool showCompass = true, bool showMyLocationButton = true, bool myLocationEnabled = true, bool zoomGesturesEnabled = true, bool scrollGesturesEnabled = true, bool tiltGesturesEnabled = true, bool rotateGesturesEnabled = true, bool doubleTapGesturesEnabled = true})
const

Properties

apiKey → String
final
doubleTapGesturesEnabled → bool
final
hashCode → int
The hash code for this object.
no setterinherited
initialCameraPosition → OlaLatLng?
final
initialZoom → double
final
key → Key?
Controls how one widget replaces another widget in the tree.
finalinherited
language → Object?
ISO 639-1 code or OlaMapsLanguage. Dynamic Maps load default-light-standard-{code} unless tileUrl is a custom style.
final
mode3d → bool
Web SDK mode: "3d" plus threeDTileset.
final
myLocationEnabled → bool
final
onControllerReady → void Function(OlaMapController controller)?
final
onMapCreated → void Function(int id)?
final
onMapError → void Function(String error)?
final
projectId → String
final
rotateGesturesEnabled → bool
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
scrollGesturesEnabled → bool
final
showCompass → bool
final
showMyLocationButton → bool
final
showZoomControls → bool
final
threeDTileset → String?
final
tileUrl → String
final
tiltGesturesEnabled → bool
final
userId → String?
final
zoomGesturesEnabled → bool
final

Methods

createElement() → StatefulElement
Creates a StatefulElement to manage this widget's location in the tree.
inherited
createState() → State<OlaMapView>
Creates the mutable state for this widget at a given location in the tree.
override
debugDescribeChildren() → List<DiagnosticsNode>
Returns a list of DiagnosticsNode objects describing this node's children.
inherited
debugFillProperties(DiagnosticPropertiesBuilder properties) → void
Add additional properties associated with the node.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toDiagnosticsNode({String? name, DiagnosticsTreeStyle? style}) → DiagnosticsNode
Returns a debug representation of the object that is used by debugging tools and by DiagnosticsNode.toStringDeep.
inherited
toString({DiagnosticLevel minLevel = DiagnosticLevel.info}) → String
A string representation of this object.
inherited
toStringDeep({String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) → String
Returns a string representation of this node and its descendants.
inherited
toStringShallow({String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) → String
Returns a one-line detailed description of the object.
inherited
toStringShort() → String
A short, textual description of this widget.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited