GeofenceRequest class

Payload for create/update geofence calls.

Constructors

GeofenceRequest({required String name, required String type, required List<List<double>> coordinates, required String projectId, String status = 'active', double? radius})
Creates a create/update request.
const

Properties

coordinates → List<List<double>>
Ring or circle-center coordinates.
final
hashCode → int
The hash code for this object.
no setterinherited
name → String
Display name.
final
projectId → String
Owning project id.
final
radius → double?
Circle radius in meters, when type is a circle.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
status → String
Lifecycle status. Defaults to active.
final
type → String
Geometry type (polygon, circle, …).
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
Serializes the request body.
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited