PlusCode class

Open Location Code (Plus Code) for a place.

Constructors

PlusCode({required String compoundCode, required String globalCode})
Creates a Plus Code pair.
PlusCode.fromJson(Map<String, dynamic> json)
Parses {compound_code, global_code}.
factory

Properties

compoundCode ↔ String
Area-relative code.
getter/setter pair
globalCode ↔ String
Global Plus Code.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
Serializes both codes.
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited