SnapToRoadResult class

Response from snap-to-road.

Constructors

SnapToRoadResult({required String status, required List<SnappedPoint> snappedPoints})
Creates a snap-to-road result.
const
SnapToRoadResult.fromJson(Map<String, dynamic> json)
Parses snap-to-road JSON.
factory

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
snappedPoints → List<SnappedPoint>
Snapped path.
final
status → String
API status string.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited