StreetViewImageId class

Nearest Street View panorama id.

Constructors

StreetViewImageId({required String imageId, Map<String, dynamic> raw = const {}})
Creates an image-id result.
const
StreetViewImageId.fromJson(Map<String, dynamic> json)
Parses an image-id JSON object.
factory

Properties

hashCode → int
The hash code for this object.
no setterinherited
imageId → String
Panorama id.
final
raw → Map<String, dynamic>
Unparsed API payload.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited