Viewport class

Southwest / northeast pair describing a map bounds.

Constructors

Viewport({required Location southwest, required Location northeast})
Creates a viewport from two corners.
Viewport.fromJson(Map<String, dynamic> json)
Parses {southwest, northeast}.
factory

Properties

hashCode → int
The hash code for this object.
no setterinherited
northeast ↔ Location
Upper-right corner.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
southwest ↔ Location
Lower-left corner.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
Serializes both corners.
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited