ola_map_view_flutter library
Classes
- OlaCameraPosition
- Camera target plus zoom / bearing / tilt.
- OlaLatLng
- Geographic coordinate used by the Ola Maps SDK.
- OlaLineType
- Line styles accepted by polylines and bezier curves.
- OlaMapController
- OlaMapsLanguage
- ISO 639-1 language codes supported by Ola Maps Places, Routing, Geocoding, and Maps APIs. Defaults to en when omitted.
- OlaMapView
- OlaRoutingService
- Service for interacting with Ola Maps Routing API
Constants
- kOlaMapsDefaultThreeDTileset → const String
- 3D tileset used by the Ola Maps Web SDK.
- kOlaMapsDefaultTileUrl → const String
-
Default vector style used by Ola Maps (
OlaMapService/ Web SDK). - kOlaMapsWebSdkUrl → const String
-
CDN URL for
olamaps-web-sdk(UMD). The Flutter web plugin also loads this automatically if the host page did not include the script tag.
Functions
-
formatOlaMapError(
Object error) → String -
isOlaMapsApiKeyConfigured(
String apiKey) → bool