AddressValidationComponent class
One component from address validation.
Constructors
- AddressValidationComponent({required String componentName, required String componentType, required String componentStatus, required String componentDetails})
-
Creates a validation component.
const
-
AddressValidationComponent.fromJson(Map<
String, dynamic> json) -
Parses a validation-component JSON object.
factory
Properties
- componentDetails → String
-
Extra detail from the API.
final
- componentName → String
-
Component display name.
final
- componentStatus → String
-
Validation status for this part.
final
- componentType → String
-
Component type.
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited