GeofenceRequest class

Constructors

GeofenceRequest({required String name, required String type, required List<List<double>> coordinates, required String projectId, String status = 'active', double? radius})
const

Properties

coordinates → List<List<double>>
final
hashCode → int
The hash code for this object.
no setterinherited
name → String
final
projectId → String
final
radius → double?
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
status → String
final
type → String
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited