GeofenceStatus class
Point-in-fence check result.
Constructors
- GeofenceStatus({required String geofenceId, required bool isInside, required String message})
-
Creates a status result.
const
-
GeofenceStatus.fromJson(Map<
String, dynamic> json) -
Parses a status JSON object.
factory
Properties
- geofenceId → String
-
Fence that was tested.
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- isInside → bool
-
Whether the query point is inside.
final
- message → String
-
Server message.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited