Olamaps class
HTTP helpers for Ola Maps REST APIs (Places, Geocode, Roads, Geofencing, Elevation, Tiles, Street View, Routing).
Constructors
- Olamaps()
Properties
- elevation ↔ OlaMapsElevation
-
getter/setter pair
- geoencoder ↔ OlamapsGeoencoder
-
getter/setter pair
- geofence ↔ OlaMapsGeofence
-
getter/setter pair
- hashCode → int
-
The hash code for this object.
no setterinherited
- language ↔ String
-
getter/setter pair
- places ↔ OlaMapsPlaces
-
getter/setter pair
- roads ↔ OlaMapsRoads
-
getter/setter pair
- routing ↔ OlaRoutingService
-
getter/setter pair
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- streetView ↔ OlaMapsStreetView
-
getter/setter pair
- tiles ↔ OlaMapsTiles
-
getter/setter pair
Methods
-
initialize(
String apiKey, {Object? language}) → void -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited